coinor.blimpy.Queues.Queue

Package coinor :: Package blimpy :: Module Queues :: Class Queue |
[hide private]
[frames] | no frames]

# Class Queue

source code

    A queue data structure built on top of a linked list
    attributes:
        items:    A list that holds objects in the queue
                  type: LinkedList
    methods:
        __init__(self):        constructor of the class
        isEmpty(self):         returns True if the queue instance is empty
        push(self,item):       inserts item to the queue
        pop(self,item):        removes first item in the queue if no item is
                               specified removes the given item if item is
                               specified
        size(self):            returns the size of the queue

Instance Methods | [hide private]
__init__(self) x.__init__(...) initializes x; see help(type(x)) for signature | source code
isEmpty(self) | source code
enqueue(self, item) | source code
push(self, item) | source code
dequeue(self, item=None) | source code
remove(self, item=None) | source code
pop(self, item=None) | source code
peek(self, item=None) | source code
size(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)